@@ -5,9 +5,9 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.5
-;; Package-Requires: ((emacs "27.1") (compat "30"))
-;; Homepage: https://github.com/minad/org-modern
+;; Version: 1.6
+;; Package-Requires: ((emacs "28.1") (compat "30"))
+;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
 
 ;; This file is part of GNU Emacs.
@@ -42,7 +42,7 @@
 (defgroup org-modern nil
   "Modern looks for Org."
   :link '(info-link :tag "Info Manual" "(org-modern)")
-  :link '(url-link :tag "Homepage" "https://github.com/minad/org-modern")
+  :link '(url-link :tag "Website" "https://github.com/minad/org-modern")
   :link '(emacs-library-link :tag "Library Source" "org-modern.el")
   :group 'org
   :prefix "org-modern-")
@@ -486,7 +486,7 @@ the font.")
 
 (defun org-modern--timestamp ()
   "Prettify timestamps."
-  (let* ((beg (match-beginning 0))
+  (let* ((beg (1- (match-beginning 1)))
          (end (match-end 0))
          (tbeg (match-beginning 2))
          (tend (match-end 2))
@@ -683,11 +683,7 @@ whole buffer; otherwise, for the line at point."
                                (t (/ (frame-char-height) 10))))
                      org-modern-label-border)))
        (list :color (face-attribute 'default :background nil t)
-             :line-width
-             ;; Emacs 28 supports different line horizontal and vertical line widths
-             (static-if (>= emacs-major-version 28)
-                 (cons -1 (- border))
-               (- border)))))))
+             :line-width (cons -1 (- border)))))))
 
 (defun org-modern--update-fringe-bitmaps ()
   "Update fringe bitmaps."
@@ -791,7 +787,7 @@ whole buffer; otherwise, for the line at point."
             ((pred stringp) `(1 '(face nil display ,org-modern-keyword)))
             (_ '(0 (org-modern--keyword)))))))
    (when org-modern-timestamp
-     '(("\\(?:<\\|\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: [[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
+     '(("\\(?:<\\|^\\[\\|[^]]\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: [[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
         (0 (org-modern--timestamp)))
        ("<[^>]+>\\(-\\)\\(-\\)<[^>]+>\\|\\[[^]]+\\]\\(?1:-\\)\\(?2:-\\)\\[[^]]+\\]"
         (1 '(face org-modern-label display #("  " 1 2 (face (:strike-through t) cursor t))) t)
